@@ -6,15 +6,19 @@ from gdsfactory.get_factories import get_cells
 from gdsfactory.pdk import Pdk
 
 from sky130 import components
-from sky130.config import module_path
+from sky130.config import PATH, module_path
 from sky130.layers import LAYER
 from sky130.tech import cross_sections
 
-__version__ = "0.0.10"
+__version__ = "0.0.11"
 
 cells = get_cells(components)
 PDK = Pdk(
-    name="sky130", cells=cells, cross_sections=cross_sections, layers=LAYER.dict()
+    name="sky130",
+    cells=cells,
+    cross_sections=cross_sections,
+    layers=LAYER.dict(),
+    sparameters_path=PATH.sparameters,
 )
 PDK.register_cells_yaml(dirpath=pathlib.Path(__file__).parent.absolute())
 PDK.activate()
